@@ -1,11 +1,12 @@
 #!/usr/bin/python3
 
-import jinja2
 import pathlib
-import shutil
 import subprocess
 import sys
 
+from jinja2 import FileSystemLoader
+from jinja2.sandbox import SandboxedEnvironment as JinjaSandboxEnv
+
 
 ###############
 # Entry point #
@@ -30,7 +31,7 @@ def main():
         return subprocess.check_output(args).decode("utf-8").strip()
 
     # Create the environment
-    env = jinja2.Environment(loader=jinja2.FileSystemLoader([str(templates)]))
+    env = JinjaSandboxEnv(loader=FileSystemLoader([str(templates)]))
 
     # Loop on all docker files
     print("Render templates:")
