@@ -93,26 +93,6 @@ VLAND_DEPLOY_TIMEOUT = 120
 # bootloader default timeout for commands
 BOOTLOADER_DEFAULT_CMD_TIMEOUT = 90
 
-# kernel boot monitoring
-# Some successful kernel builds end the boot with this string
-KERNEL_FREE_UNUSED_MSG = r"Freeing unused kernel memory"
-# Some successful kernel builds end the boot with this string
-KERNEL_FREE_INIT_MSG = r"Freeing init memory"
-# exception
-KERNEL_EXCEPTION_MSG = r"-+\[ cut here \]-+\s+(.*\s+-+\[ end trace (\w*) \]-+)"
-# stack trace
-KERNEL_TRACE_MSG = r"Stack:\s+(.*\s+-+\[ end trace (\w*) \]-+)"
-# unhandled fault
-KERNEL_FAULT_MSG = r"(Unhandled fault.*)\r\n"
-# oops
-KERNEL_OOPS_MSG = r"^[^\n]+Oops(?: -|:).*?$"
-# panic
-KERNEL_PANIC_MSG = r"Kernel panic - (.*) end Kernel panic"
-# warning
-KERNEL_WARNING_MSG = r"^[^\n]+WARNING:.*?$"
-# bug
-KERNEL_BUG_MSG = r"^[^\n]+BUG:.*?$"
-
 # Login incorrect message
 LOGIN_INCORRECT_MSG = "Login incorrect"
 # Login incorrect message
@@ -172,3 +152,4 @@ VALID_DISPATCHER_IP_PROTOCOLS = ["http", "nfs", "tftp"]
 
 # worker daemon data directory
 WORKER_DIR = "/var/lib/lava/dispatcher/worker"
+DOCKER_WORKER_DIR = "/var/lib/lava/dispatcher/docker-worker"
