@@ -33,6 +33,7 @@ def schema():
         Optional(
             "auto_login"
         ): boot.auto_login(),  # TODO: if auto_login => prompt is required
+        Optional("deploy"): bool,
         Optional("command"): str,
         Optional("kernel"): str,
         Optional("dtb"): str,
@@ -40,5 +41,6 @@ def schema():
         Optional("options"): [str],
         Optional("kernel-config"): str,
         Optional("transfer_overlay"): boot.transfer_overlay(),
+        Optional("on_panic"): bool,
     }
     return {**boot.schema(), **base}
