@@ -18,29 +18,28 @@
 # along
 # with this program; if not, see <http://www.gnu.org/licenses>.
 
-from collections import OrderedDict
-import logging
 import copy
-from functools import reduce
-import pexpect
-import time
-import types
-import traceback
+import logging
 import shlex
 import subprocess  # nosec - internal
+import time
+import traceback
 import warnings
+from functools import reduce
+
+import pexpect
 
 from lava_common.decorators import nottest
-from lava_common.timeout import Timeout
 from lava_common.exceptions import (
-    LAVABug,
-    LAVAError,
     InfrastructureError,
     JobError,
-    TestError,
+    LAVABug,
+    LAVAError,
     LAVATimeoutError,
+    TestError,
 )
 from lava_common.log import YAMLLogger
+from lava_common.timeout import Timeout
 from lava_dispatcher.utils.strings import seconds_to_str
 
 
@@ -131,6 +130,7 @@ class Pipeline:
         # 1/ the global action timeout
         # 2/ the individual action timeout
         # 3/ the action block timeout
+        # 4/ the individual action block timeout
 
         action._override_action_timeout(dict_merge_get(timeouts, "action"))
         action._override_action_timeout(
@@ -138,6 +138,11 @@ class Pipeline:
         )
         action._override_action_timeout(parameters.get("timeout"))
 
+        if parameters.get("timeouts"):
+            action._override_action_timeout(
+                dict_merge_get([parameters.get("timeouts")], action.name)
+            )
+
         action._override_connection_timeout(dict_merge_get(timeouts, "connection"))
         action._override_connection_timeout(
             subdict_merge_get(timeouts, "connections", action.name)
@@ -145,7 +150,7 @@ class Pipeline:
 
         action.parameters = parameters
 
-    def describe(self, verbose=True):
+    def describe(self):
         """
         Describe the current pipeline, recursing through any
         internal pipelines.
@@ -153,13 +158,20 @@ class Pipeline:
         """
         desc = []
         for action in self.actions:
-            if verbose:
-                current = action.explode()
-            else:
-                cls = str(type(action))[8:-2].replace("lava_dispatcher.", "")
-                current = {"class": cls, "name": action.name}
+            cls = str(type(action))[8:-2].replace("lava_dispatcher.", "")
+            current = {
+                "class": cls,
+                "name": action.name,
+                "level": action.level,
+                "max_retries": action.max_retries,
+                "description": action.description,
+                "summary": action.summary,
+                "timeout": action.timeout.duration,
+            }
+            if hasattr(action, "url"):
+                current["url"] = action.url.geturl()
             if action.pipeline is not None:
-                sub_desc = action.pipeline.describe(verbose)
+                sub_desc = action.pipeline.describe()
                 if sub_desc:
                     current["pipeline"] = sub_desc
             desc.append(current)
@@ -831,80 +843,6 @@ class Action:
         if self.pipeline:
             self.pipeline.cleanup(connection)
 
-    def explode(self):
-        """
-        serialisation support
-        Omit our objects marked as internal by inheriting form InternalObject instead of object,
-        e.g. SignalMatch
-        """
-        data = {}
-        attrs = set(
-            (
-                attr
-                for attr in dir(self)
-                if not attr.startswith("_")
-                and getattr(self, attr)
-                and not isinstance(getattr(self, attr), types.MethodType)
-                and not isinstance(getattr(self, attr), InternalObject)
-            )
-        )
-
-        # noinspection PySetFunctionToLiteral
-        skip_set = set(
-            [
-                "pipeline",
-                "job",
-                "logger",
-                "pipeline",
-                "default_fixupdict",
-                "pattern",
-                "parameters",
-                "SignalDirector",
-                "signal_director",
-            ]
-        )
-        for attr in attrs - skip_set:
-            if attr == "timeout":
-                data["timeout"] = {
-                    "duration": self.timeout.duration,
-                    "name": self.timeout.name,
-                }
-            elif attr == "connection_timeout":
-                data["timeout"] = {
-                    "duration": self.timeout.duration,
-                    "name": self.timeout.name,
-                }
-            elif attr == "url":
-                data["url"] = self.url.geturl()
-            elif attr == "vcs":
-                data[attr] = getattr(self, attr).url
-            elif attr == "protocols":
-                data["protocols"] = {}
-                for protocol in getattr(self, attr):
-                    data["protocols"][protocol.name] = {}
-                    protocol_attrs = set(
-                        (
-                            attr
-                            for attr in dir(protocol)
-                            if not attr.startswith("_")
-                            and getattr(protocol, attr)
-                            and not isinstance(
-                                getattr(protocol, attr), types.MethodType
-                            )
-                            and not isinstance(getattr(protocol, attr), InternalObject)
-                        )
-                    )
-                    for protocol_attr in protocol_attrs:
-                        if protocol_attr not in ["logger"]:
-                            data["protocols"][protocol.name][protocol_attr] = getattr(
-                                protocol, protocol_attr
-                            )
-            elif isinstance(getattr(self, attr), OrderedDict):
-                data[attr] = dict(getattr(self, attr))
-            else:
-                data[attr] = getattr(self, attr)
-        return data
-
     def get_namespace_keys(self, action, parameters=None):
         """Return the keys for the given action"""
         params = parameters if parameters else self.parameters
