@@ -23,9 +23,9 @@ import re
 import shlex
 import subprocess
 
-from lava_dispatcher.action import Pipeline, Action, JobError
-from lava_dispatcher.logical import Boot, RetryAction
+from lava_dispatcher.action import Action, JobError, Pipeline
 from lava_dispatcher.connections.serial import ConnectDevice
+from lava_dispatcher.logical import Boot, RetryAction
 from lava_dispatcher.power import ResetDevice
 from lava_dispatcher.utils.udev import WaitDeviceBoardID
 
