@@ -21,9 +21,9 @@
 from lava_dispatcher.action import Pipeline
 from lava_dispatcher.actions.boot import AutoLoginAction, BootHasMixin, OverlayUnpack
 from lava_dispatcher.actions.boot.environment import ExportDeviceEnvironment
-from lava_dispatcher.logical import Boot, RetryAction
-from lava_dispatcher.power import ResetDevice, PrePower, PreOs
 from lava_dispatcher.connections.serial import ConnectDevice
+from lava_dispatcher.logical import Boot, RetryAction
+from lava_dispatcher.power import PreOs, PrePower, ResetDevice
 from lava_dispatcher.shell import ExpectShellSession
 
 
