@@ -19,10 +19,10 @@
 # with this program; if not, see <http://www.gnu.org/licenses>.
 
 
-from lava_dispatcher.logical import Boot
 from lava_common.exceptions import InfrastructureError
 from lava_dispatcher.action import Action, Pipeline
-from lava_dispatcher.power import PowerOn, PowerOff
+from lava_dispatcher.logical import Boot
+from lava_dispatcher.power import PowerOff, PowerOn
 
 
 class RecoveryBoot(Boot):
