@@ -19,10 +19,12 @@
 # with this program; if not, see <http://www.gnu.org/licenses>.
 
 import json
+import re
+
+from lava_common.exceptions import MultinodeProtocolTimeoutError, TestError
 from lava_common.timeout import Timeout
-from lava_common.exceptions import TestError, MultinodeProtocolTimeoutError
-from lava_dispatcher.actions.test.monitor import TestMonitor
 from lava_dispatcher.actions.test.interactive import TestInteractive
+from lava_dispatcher.actions.test.monitor import TestMonitor
 from lava_dispatcher.actions.test.shell import TestShell, TestShellAction
 from lava_dispatcher.logical import LavaTest
 from lava_dispatcher.protocols.multinode import MultinodeProtocol
@@ -83,7 +85,7 @@ class MultinodeTestShell(LavaTest):
 
     @classmethod
     def needs_deployment_data(cls, parameters):
-        """ Some, not all, deployments will want deployment_data """
+        """Some, not all, deployments will want deployment_data"""
         return get_subaction_class(parameters).needs_deployment_data(parameters)
 
     @classmethod
@@ -143,7 +145,10 @@ class MultinodeMixin:
         if event == "multinode":
             name, params = test_connection.match.groups()
             self.logger.debug("Received Multi_Node API <LAVA_%s>" % name)
-            params = params.split()
+            if name == "SEND":
+                params = re.split(r"\s+(?=\w+(?:=))", params)
+            else:
+                params = params.split()
             test_case_name = "%s-%s" % (name, params[0])  # use the messageID
             self.logger.debug("messageID: %s", test_case_name)
 
