@@ -18,12 +18,12 @@
 # along
 # with this program; if not, see <http://www.gnu.org/licenses>.
 
-from lava_dispatcher.connection import RECOGNIZED_TAGS
-from lava_dispatcher.utils.shell import which
-from lava_dispatcher.logical import RetryAction
+from lava_common.exceptions import InfrastructureError, JobError
 from lava_dispatcher.action import Action, Pipeline
-from lava_common.exceptions import JobError, InfrastructureError
+from lava_dispatcher.connection import RECOGNIZED_TAGS
+from lava_dispatcher.logical import RetryAction
 from lava_dispatcher.shell import ShellCommand, ShellSession
+from lava_dispatcher.utils.shell import which
 
 
 class ConnectDevice(Action):
