@@ -26,16 +26,11 @@ class OptionalContainerFastbootAction(OptionalContainerAction):
     def get_fastboot_cmd(self, cmd):
         serial_number = self.job.device["fastboot_serial_number"]
         fastboot_opts = self.job.device["fastboot_options"]
-        fastboot_cmd = (
-            self.driver.get_command_prefix()
-            + ["fastboot", "-s", serial_number]
-            + cmd
-            + fastboot_opts
-        )
+        fastboot_cmd = ["fastboot", "-s", serial_number] + cmd + fastboot_opts
         return fastboot_cmd
 
     def run_fastboot(self, cmd):
-        self.run_cmd(self.get_fastboot_cmd(cmd))
+        self.run_maybe_in_container(self.get_fastboot_cmd(cmd))
 
     def get_fastboot_output(self, cmd, **kwargs):
-        return self.parsed_command(self.get_fastboot_cmd(cmd), **kwargs)
+        return self.get_output_maybe_in_container(self.get_fastboot_cmd(cmd), **kwargs)
