@@ -19,26 +19,70 @@
 # with this program; if not, see <http://www.gnu.org/licenses>.
 
 import time
+
 import pexpect
-from lava_dispatcher.action import Action
-from lava_common.exceptions import TestError, JobError, LAVABug
-from lava_common.constants import (
-    KERNEL_BUG_MSG,
-    KERNEL_FREE_UNUSED_MSG,
-    KERNEL_FREE_INIT_MSG,
-    KERNEL_EXCEPTION_MSG,
-    KERNEL_FAULT_MSG,
-    KERNEL_OOPS_MSG,
-    KERNEL_PANIC_MSG,
-    KERNEL_WARNING_MSG,
-    KERNEL_TRACE_MSG,
-    METADATA_MESSAGE_LIMIT,
-)
-from lava_dispatcher.utils.strings import seconds_to_str
+
+from lava_common.exceptions import JobError, TestError
 from lava_common.log import YAMLLogger
+from lava_dispatcher.utils.strings import seconds_to_str
+
+# kernel boot monitoring
+KERNEL_MESSAGES = [
+    {
+        "start": r"-\[ cut here \]",
+        "end": r"-+\[ end trace \w* \]-+[^\n]*\r",
+        "kind": None,
+    },
+    {
+        "start": r"Unhandled fault",
+        "end": r"\r",
+        "kind": "fault",
+    },
+    {
+        "start": r"BUG: KCSAN:",
+        "end": r"=+\r",
+        "kind": "kcsan",
+    },
+    {
+        "start": r"BUG: KASAN:",
+        "end": r"=+\r",
+        "kind": "kasan",
+    },
+    {
+        "start": r"BUG: KFENCE:",
+        "end": r"=+\r",
+        "kind": "kfence",
+    },
+    {
+        "start": r"Oops(?: -|:)",
+        "end": r"\r",
+        "kind": "oops",
+    },
+    {
+        "start": r"WARNING:",
+        "end": r"end trace[^\r]*\r",
+        "kind": "warning",
+    },
+    {
+        "start": r"(kernel BUG at|BUG:)",
+        "end": r"\r",
+        "kind": "bug",
+    },
+    {
+        "start": r"invalid opcode:",
+        "end": r"\r",
+        "kind": "invalid opcode",
+    },
+    {
+        "start": r"Kernel panic - not syncing",
+        "end": r"end Kernel panic[^\r]*\r",
+        "kind": "panic",
+        "fatal": True,
+    },
+]
 
 
-class LinuxKernelMessages(Action):
+class LinuxKernelMessages:
     """
     Adds prompt strings to the boot operation
     to monitor for kernel panics and error strings.
@@ -55,43 +99,9 @@ class LinuxKernelMessages(Action):
     description = "Test kernel messages during boot."
     summary = "Check for kernel errors, faults and panics."
 
-    EXCEPTION = 0
-    FAULT = 1
-    PANIC = 2
-    TRACE = 3
-    WARNING = 4
-    OOPS = 5
-    BUG = 6
-    # these can be omitted by InitMessages
-    FREE_UNUSED = 7
-    FREE_INIT = 8
-
-    MESSAGE_CHOICES = (
-        (EXCEPTION, KERNEL_EXCEPTION_MSG, "exception"),
-        (FAULT, KERNEL_FAULT_MSG, "fault"),
-        (PANIC, KERNEL_PANIC_MSG, "panic"),
-        (TRACE, KERNEL_TRACE_MSG, "trace"),
-        (WARNING, KERNEL_WARNING_MSG, "warning"),
-        (OOPS, KERNEL_OOPS_MSG, "oops"),
-        (BUG, KERNEL_BUG_MSG, "bug"),
-        (FREE_UNUSED, KERNEL_FREE_UNUSED_MSG, "success"),
-        (FREE_INIT, KERNEL_FREE_INIT_MSG, "success"),
-    )
-
-    def __init__(self):
-        super().__init__()
-        self.messages = self.get_kernel_prompts()
-        self.existing_prompt = None
-        for choice in self.MESSAGE_CHOICES:
-            self.messages.append(choice[1])
-
-    @classmethod
-    def get_kernel_prompts(cls):
-        return [prompt[1] for prompt in cls.MESSAGE_CHOICES]
-
     @classmethod
     def get_init_prompts(cls):
-        return [prompt[1] for prompt in cls.MESSAGE_CHOICES[: cls.FREE_UNUSED]]
+        return [msg["start"] for msg in KERNEL_MESSAGES]
 
     @classmethod
     def parse_failures(
@@ -101,9 +111,7 @@ class LinuxKernelMessages(Action):
         Returns a list of dictionaries of matches for failure strings and
         other kernel messages.
 
-        If kernel_prompts are in use, a success result is returned containing
-        details of which of KERNEL_FREE_UNUSED_MSG and KERNEL_FREE_INIT_MSG
-        were parsed. If the returned dictionary only contains this success
+        If the returned dictionary only contains this success
         message, then the the kernel-messages action can be deemed as pass.
 
         The init prompts exclude these messages, so a successful init parse
@@ -117,22 +125,12 @@ class LinuxKernelMessages(Action):
         Always returns a list, the list may be empty.
         """
         results = []  # wrap inside a dict to use in results
-        res = "pass"
+        result = "pass"
         halt = None
-        init = False
         start = time.monotonic()
-        if not connection:
-            return results
-        if cls.MESSAGE_CHOICES[cls.FREE_UNUSED][1] in connection.prompt_str:
-            if cls.MESSAGE_CHOICES[cls.FREE_INIT][1] in connection.prompt_str:
-                init = True
-        remaining = max_end_time - start
-        if remaining < 0:
-            raise LAVABug(
-                "Invalid time remaining: max: %s start: %s" % (max_end_time, start)
-            )
 
         while True:
+            remaining = max_end_time - time.monotonic()
             action.logger.debug(
                 "[%s] Waiting for messages, (timeout %s)",
                 action.name,
@@ -143,7 +141,7 @@ class LinuxKernelMessages(Action):
                     index = connection.force_prompt_wait(remaining)
                 else:
                     index = connection.wait(max_end_time)
-            except (pexpect.EOF, pexpect.TIMEOUT, TestError):
+            except (pexpect.EOF, TestError):
                 msg = "Failed to match - connection timed out handling messages."
                 action.logger.warning(msg)
                 action.errors = msg
@@ -154,57 +152,83 @@ class LinuxKernelMessages(Action):
                     "Matched prompt #%s: %s", index, connection.prompt_str[index]
                 )
             message = connection.raw_connection.after
-            if index in [cls.TRACE, cls.EXCEPTION, cls.WARNING, cls.BUG]:
-                res = "fail"
-                action.logger.warning(
-                    "%s: %s" % (action.name, cls.MESSAGE_CHOICES[index][2])
-                )
-                # TRACE may need a newline to force a prompt (only when not using auto-login)
-                if not auto_login:
-                    connection.sendline(connection.check_char)
-                # this is allowable behaviour, not a failure.
-                results.append(
-                    {
-                        cls.MESSAGE_CHOICES[index][2]: cls.MESSAGE_CHOICES[index][1],
-                        "message": message[:METADATA_MESSAGE_LIMIT],
-                    }
-                )
-                continue
-            elif index == cls.PANIC:
-                res = "fail"
-                action.logger.error(
-                    "%s %s" % (action.name, cls.MESSAGE_CHOICES[index][2])
-                )
-                results.append(
-                    {
-                        cls.MESSAGE_CHOICES[index][2]: cls.MESSAGE_CHOICES[index][1],
-                        "message": message[:METADATA_MESSAGE_LIMIT],
-                    }
-                )
-                halt = message[:METADATA_MESSAGE_LIMIT]
+            if index is None:
                 break
+            if index < len(KERNEL_MESSAGES):
+                # Capture the start of the line
+                if "\n" in connection.raw_connection.before:
+                    start_line = connection.raw_connection.before.rindex("\n")
+                    message = (
+                        connection.raw_connection.before[start_line + 1 :] + message
+                    )
+                else:
+                    message = connection.raw_connection.before + message
+
+                # Capture the end of the kernel message
+                previous_prompts = connection.prompt_str
+                connection.prompt_str = [
+                    KERNEL_MESSAGES[index]["end"]
+                ] + previous_prompts[len(KERNEL_MESSAGES) :]
+                try:
+                    sub_index = connection.wait(max_end_time, max_searchwindowsize=True)
+                except (pexpect.EOF, TestError):
+                    msg = "Failed to match end of kernel error"
+                    action.logger.warning(msg)
+                    action.errors = msg
+                    break
+                if sub_index != 0:
+                    action.logger.warning("Unable to match end of the kernel message")
+                    break
+                message = (
+                    message
+                    + connection.raw_connection.before
+                    + connection.raw_connection.after[:-1]  # Remove ending "\r"
+                )
+                connection.prompt_str = previous_prompts
+
+                # Classify the errors
+                kind = KERNEL_MESSAGES[index]["kind"]
+                if kind is None:
+                    if "Oops" in message:
+                        kind = "oops"
+                    elif "BUG" in message:
+                        kind = "bug"
+                    elif "WARNING" in message:
+                        kind = "warning"
+                    else:
+                        kind = "unknown"
+
+                if KERNEL_MESSAGES[index].get("fatal"):
+                    result = "fail"
+                    action.logger.error("%s kernel %r" % (action.name, kind))
+                    halt = message
+                else:
+                    action.logger.warning("%s: kernel %r" % (action.name, kind))
+
+                # TRACE may need a newline to force a prompt (only when not using auto-login)
+                if not auto_login and KERNEL_MESSAGES[index]["kind"] == "trace":
+                    connection.sendline(connection.check_char)
+
+                results.append(
+                    {
+                        "kind": kind,
+                        "message": message,
+                    }
+                )
+                if KERNEL_MESSAGES[index].get("fatal"):
+                    break
+                else:
+                    continue
             elif fail_msg and index and fail_msg == connection.prompt_str[index]:
-                res = "fail"
+                result = "fail"
                 # user has declared this message to be terminal for this test job.
                 halt = "Matched job-specific failure message: '%s'" % fail_msg
                 action.logger.error("%s %s" % (action.name, halt))
                 results.append({"message": "kernel-messages"})
-            elif index and index == cls.FREE_UNUSED or index == cls.FREE_INIT:
-                if init and index <= cls.FREE_INIT:
-                    results.append(
-                        {
-                            cls.MESSAGE_CHOICES[index][2]: cls.MESSAGE_CHOICES[index][
-                                1
-                            ],
-                            "message": "kernel-messages",
-                        }
-                    )
-                    continue
-                else:
-                    results.append({"success": connection.prompt_str[index]})
-                    break
+                break
             else:
                 break
+
         # record a specific result for the kernel messages for later debugging.
         if isinstance(action.logger, YAMLLogger):
             action.logger.results(
@@ -214,7 +238,7 @@ class LinuxKernelMessages(Action):
                     "case": cls.name,
                     "level": action.level,
                     "duration": "%.02f" % (time.monotonic() - start),
-                    "result": res,
+                    "result": result,
                     "extra": {"extra": results},
                 }
             )
@@ -225,31 +249,3 @@ class LinuxKernelMessages(Action):
         # allow calling actions to also pick up failures
         # without overriding their own success result, if any.
         return results
-
-    def validate(self):
-        super().validate()
-        if not self.messages:
-            self.errors = "Unable to build a list of kernel messages to monitor."
-
-    def run(self, connection, max_end_time):
-        if not connection:
-            return connection
-        if not self.existing_prompt:
-            self.existing_prompt = connection.prompt_str[:]
-            connection.prompt_str = self.get_kernel_prompts()
-        if isinstance(self.existing_prompt, list):
-            connection.prompt_str.extend(self.existing_prompt)
-        else:
-            connection.prompt_str.append(self.existing_prompt)
-        self.logger.debug(connection.prompt_str)
-        results = self.parse_failures(connection, self, max_end_time, None)
-        if len(results) > 1:
-            self.results = {"fail": results}
-        elif len(results) == 1:
-            self.results = {
-                "success": self.name,
-                "message": results[0]["message"],  # the matching prompt
-            }
-        else:
-            self.results = {"result": "skipped"}
-        return connection
