@@ -18,28 +18,27 @@
 # along with LAVA.  If not, see <http://www.gnu.org/licenses/>.
 
 import io
+
 import junit_xml
 import tap
+from django.http.response import FileResponse, HttpResponse
+from rest_framework import status, viewsets
+from rest_framework.permissions import BasePermission
 
 import lava_server.compat  # pylint: disable=unused-import
+from lava_results_app.models import TestCase
+from lava_scheduler_app.dbutils import testjob_submission
+from lava_scheduler_app.logutils import logs_instance
 from lava_scheduler_app.models import (
     Device,
-    DeviceType,
     DevicesUnavailableException,
+    DeviceType,
     TestJob,
     Worker,
 )
-from lava_scheduler_app.dbutils import testjob_submission
 from lava_scheduler_app.schema import SubmissionException
-from lava_results_app.models import TestCase
-from lava_scheduler_app.logutils import logs_instance
 from linaro_django_xmlrpc.models import AuthToken
 
-from django.http.response import FileResponse, HttpResponse
-
-from rest_framework import status, viewsets
-from rest_framework.permissions import BasePermission
-
 try:
     from rest_framework.decorators import detail_route
 except ImportError:
@@ -50,7 +49,7 @@ except ImportError:
 
 
 from rest_framework.authtoken.views import ObtainAuthToken
-from rest_framework.exceptions import NotFound, AuthenticationFailed
+from rest_framework.exceptions import AuthenticationFailed, NotFound
 from rest_framework.pagination import PageNumberPagination
 from rest_framework.response import Response
 
@@ -120,7 +119,7 @@ class TestJobViewSet(viewsets.ModelViewSet):
 
     queryset = TestJob.objects
     serializer_class = serializers.TestJobSerializer
-    filter_fields = (
+    filterset_fields = (
         "submitter",
         "viewing_groups",
         "description",
@@ -141,7 +140,7 @@ class TestJobViewSet(viewsets.ModelViewSet):
         "failure_comment",
     )
     ordering_fields = ("id", "start_time", "end_time", "submit_time")
-    filter_class = filters.TestJobFilter
+    filterset_class = filters.TestJobFilter
 
     def get_queryset(self):
         return (
@@ -331,7 +330,7 @@ class TestJobViewSet(viewsets.ModelViewSet):
 class DeviceTypeViewSet(viewsets.ModelViewSet):
     queryset = DeviceType.objects
     serializer_class = serializers.DeviceTypeSerializer
-    filter_fields = (
+    filterset_fields = (
         "name",
         "architecture",
         "processor",
@@ -346,7 +345,7 @@ class DeviceTypeViewSet(viewsets.ModelViewSet):
         "health_denominator",
         "display",
     )
-    filter_class = filters.DeviceTypeFilter
+    filterset_class = filters.DeviceTypeFilter
 
     def get_queryset(self):
         return DeviceType.objects.visible_by_user(self.request.user).prefetch_related(
@@ -362,7 +361,7 @@ class DeviceTypeViewSet(viewsets.ModelViewSet):
 class DeviceViewSet(viewsets.ReadOnlyModelViewSet):
     queryset = Device.objects
     serializer_class = serializers.DeviceSerializer
-    filter_fields = (
+    filterset_fields = (
         "hostname",
         "device_type",
         "device_version",
@@ -388,7 +387,7 @@ class DeviceViewSet(viewsets.ReadOnlyModelViewSet):
         "worker_host",
         "is_synced",
     )
-    filter_class = filters.DeviceFilter
+    filterset_class = filters.DeviceFilter
 
     def get_queryset(self):
         query = (
@@ -409,7 +408,7 @@ class DeviceViewSet(viewsets.ReadOnlyModelViewSet):
 class WorkerViewSet(viewsets.ReadOnlyModelViewSet):
     queryset = Worker.objects
     serializer_class = serializers.WorkerSerializer
-    filter_fields = "__all__"
+    filterset_fields = "__all__"
     ordering_fields = "__all__"
 
     def get_queryset(self):
