@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
-from django.db import models, migrations
 import django.db.models.deletion
 from django.conf import settings
+from django.db import migrations, models
 
 
 class Migration(migrations.Migration):
