@@ -21,7 +21,6 @@ from django import template
 from django.template.defaultfilters import stringfilter
 from django.utils.safestring import mark_safe
 
-
 register = template.Library()
 
 
@@ -30,5 +29,5 @@ register = template.Library()
 def make_jquery_safe(value):
     chars = "!()<>=$%&^!@+*#?~|'\\;`"
     for char in chars:
-        value = mark_safe(value.replace(char, '\\\\%s' % char))
+        value = mark_safe(value.replace(char, "\\\\%s" % char))
     return value
