@@ -18,21 +18,20 @@
 # along with LAVA.  If not, see <http://www.gnu.org/licenses/>.
 
 import os
-from datetime import timedelta
-import voluptuous
 import xmlrpc.client
+from datetime import timedelta
 
+import voluptuous
 from django.conf import settings
 from django.utils import timezone
 
-from linaro_django_xmlrpc.models import ExposedV2API
-
+from lava_common import schemas
 from lava_common.compat import yaml_safe_load
-import lava_common.schemas as schemas
+from lava_results_app.models import TestCase
 from lava_scheduler_app.api import SchedulerAPI
 from lava_scheduler_app.logutils import logs_instance
 from lava_scheduler_app.models import TestJob
-from lava_results_app.models import TestCase
+from linaro_django_xmlrpc.models import ExposedV2API
 
 
 def load_optional_file(filename):
