@@ -1,9 +1,8 @@
 # -*- coding: utf-8 -*-
-from django.db import models, migrations, DEFAULT_DB_ALIAS, connections
-from django.db.migrations.recorder import MigrationRecorder
 import django.db.models.deletion
 from django.conf import settings
-
+from django.db import DEFAULT_DB_ALIAS, connections, migrations, models
+from django.db.migrations.recorder import MigrationRecorder
 
 connection = connections[DEFAULT_DB_ALIAS]
 recorder = MigrationRecorder(connection)
