@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-from django.db import models, migrations
+from django.db import migrations, models
 
 
 class Migration(migrations.Migration):
