@@ -18,24 +18,41 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with LAVA.  If not, see <http://www.gnu.org/licenses/>.
 
+import logging
 import xmlrpc.client
+from functools import wraps
 
-from django.http import Http404
 from django.conf import settings
-from django.contrib.auth.models import Group
+from django.contrib.auth.models import Group, User
 from django.core.exceptions import PermissionDenied
+from django.http import Http404
 
 from lava_common.compat import yaml_safe_dump
 from lava_common.version import __version__
 from lava_scheduler_app.api import check_perm
-from lava_scheduler_app.views import get_restricted_job
 from lava_scheduler_app.models import (
     Device,
     DeviceType,
     GroupDevicePermission,
     GroupDeviceTypePermission,
 )
-from linaro_django_xmlrpc.models import errors, Mapper, SystemAPI
+from lava_scheduler_app.views import get_restricted_job
+from linaro_django_xmlrpc.models import Mapper, SystemAPI, errors
+
+
+def check_staff(f):
+    """decorator to check that the caller has staff permissions"""
+
+    @wraps(f)
+    def wrapper(self, *args, **kwargs):
+        self._authenticate()
+        if not self.user.is_staff:
+            raise xmlrpc.client.Fault(errors.FORBIDDEN, "forbidden")
+        elif not self.user.is_active:
+            raise xmlrpc.client.Fault(errors.AUTH_BLOCKED, "user is blocked")
+        return f(self, *args, **kwargs)
+
+    return wrapper
 
 
 class LavaSystemAPI(SystemAPI):
@@ -43,6 +60,11 @@ class LavaSystemAPI(SystemAPI):
     Extend the default SystemAPI with a 'whoami' method.
     """
 
+    def __init__(self, context):
+        logging.basicConfig()
+        self.logger = logging.getLogger("lava-server-api")
+        super().__init__(context)
+
     def whoami(self):
         """
         Name
@@ -479,6 +501,49 @@ class LavaSystemAPI(SystemAPI):
                 )
         return yaml_safe_dump(network_map)
 
+    @check_staff
+    def set_user_groups(self, user, groups):
+        """
+        Name
+        ----
+        set_user_groups(`user`, `groups`):
+
+        Description
+        -----------
+
+        Set the groups a given user belongs to.
+
+        This function requires staff access.
+
+        Arguments
+        ---------
+        user: str
+            user (identified by email) whose groups will be changed
+        groups: Array of str
+            the name of each group to which this user belongs
+
+        Return value
+        ------------
+        No return value.
+        """
+        try:
+            user = User.objects.get(email=user)
+        except User.DoesNotExist:
+            raise xmlrpc.client.Fault(errors.BAD_REQUEST, "please use an existing user")
+
+        if not isinstance(groups, list):
+            raise xmlrpc.client.Fault(errors.BAD_REQUEST, "groups must be a list")
+
+        transformed_groups = Group.objects.filter(name__in=groups)
+        missing = set(groups) - {t.name for t in transformed_groups}
+        if missing:
+            missing = ", ".join(missing)
+            self.logger.debug(
+                f"set_user_groups: skipped groups {missing} which do not exist"
+            )
+
+        user.groups.set(transformed_groups)
+
     @check_perm("lava_scheduler_app.change_devicetype")
     def assign_perm_device_type(self, perm, device_type, group):
         """
