@@ -18,12 +18,11 @@
 # along
 # with this program; if not, see <http://www.gnu.org/licenses>.
 
-from django.utils.version import get_version
-from django.core.management.base import CommandParser
-from rest_framework_extensions import __version__ as DRFE_VERSION_STR
-import rest_framework_filters as filters
 import junit_xml
-
+import rest_framework_filters as filters
+from django.core.management.base import CommandParser
+from django.utils.version import get_version
+from rest_framework_extensions import __version__ as DRFE_VERSION_STR
 
 DJANGO_VERSION = get_version()
 DRFE_VERSION = [int(n) for n in DRFE_VERSION_STR.split(".")]
@@ -44,11 +43,10 @@ try:
     def RelatedFilter(cls, name, queryset):
         return filters.RelatedFilter(cls, field_name=name, queryset=queryset)
 
-
 except ImportError:
-    from rest_framework_filters.backends import (
+    from rest_framework_filters.backends import (  # noqa
         DjangoFilterBackend as RestFrameworkFilterBackend,
-    )  # noqa
+    )
 
     # Keep the original version
     def RelatedFilter(cls, name, queryset):
@@ -126,7 +124,6 @@ try:
             return {"paginator_class": FixedLazyPaginator}
         return {"paginator_class": LazyPaginator}
 
-
 except ImportError:
     from django.core.paginator import EmptyPage, Page, PageNotAnInteger, Paginator
     from django.utils.translation import gettext as _
