@@ -22,19 +22,18 @@ XML-RPC views
 
 import base64
 
+from django.conf import settings
 from django.contrib.auth.decorators import login_required
 from django.contrib.sites.models import Site
-from django.urls import reverse
-from django.conf import settings
 from django.http import HttpResponse, HttpResponseRedirect
 from django.shortcuts import get_object_or_404, redirect, render
+from django.urls import reverse
 from django.views.decorators.csrf import csrf_exempt
 
-from linaro_django_xmlrpc.models import AuthToken, CallContext, Dispatcher, SystemAPI
-from linaro_django_xmlrpc.forms import AuthTokenForm
-
 from lava_server.bread_crumbs import BreadCrumb, BreadCrumbTrail
 from lava_server.views import index as lava_index
+from linaro_django_xmlrpc.forms import AuthTokenForm
+from linaro_django_xmlrpc.models import AuthToken, CallContext, Dispatcher, SystemAPI
 
 
 @csrf_exempt
@@ -50,51 +49,50 @@ def handler(request, mapper, help_view):
     want to show help specific to your mapper you must specify help_view. It
     accepts whatever django.shortcuts.redirect() would.
     """
-    if len(request.body):
-        raw_data = request.body
-        dispatcher = Dispatcher(mapper)
-
-        auth_string = request.META.get("HTTP_AUTHORIZATION")
-
-        if auth_string is not None:
-            if " " not in auth_string:
-                return HttpResponse("Invalid HTTP_AUTHORIZATION header", status=400)
-            scheme, value = auth_string.split(" ", 1)
-            if scheme != "Basic":
-                return HttpResponse(
-                    "Unsupported HTTP_AUTHORIZATION header, only Basic scheme is supported",
-                    status=400,
-                )
-            try:
-                decoded_value = base64.standard_b64decode(value).decode("utf-8")
-            except (TypeError, UnicodeDecodeError):
-                return HttpResponse(
-                    "Corrupted HTTP_AUTHORIZATION header, bad base64 encoding",
-                    status=400,
-                )
-            try:
-                username, secret = decoded_value.split(":", 1)
-            except ValueError:
-                return HttpResponse(
-                    "Corrupted HTTP_AUTHORIZATION header, no user:pass", status=400
-                )
-            user = AuthToken.get_user_for_secret(username, secret)
-            if user is None:
-                response = HttpResponse("Invalid token", status=401)
-                response[
-                    "WWW-Authenticate"
-                ] = 'Basic realm="XML-RPC Authentication token"'
-                return response
-        else:
-            user = request.user
-        result = dispatcher.marshalled_dispatch(raw_data, user, request)
-        response = HttpResponse(content_type="application/xml")
-        response.write(result)
-        response["Content-length"] = str(len(response.content))
-        return response
-    else:
+    if len(request.body) == 0 or request.method != "POST":
         return redirect(help_view)
 
+    raw_data = request.body
+    dispatcher = Dispatcher(mapper)
+
+    auth_string = request.META.get("HTTP_AUTHORIZATION")
+
+    if auth_string is not None:
+        if " " not in auth_string:
+            return HttpResponse("Invalid HTTP_AUTHORIZATION header", status=400)
+        scheme, value = auth_string.split(" ", 1)
+        if scheme != "Basic":
+            return HttpResponse(
+                "Unsupported HTTP_AUTHORIZATION header, only Basic scheme is supported",
+                status=400,
+            )
+        try:
+            decoded_value = base64.standard_b64decode(value).decode("utf-8")
+        except (TypeError, UnicodeDecodeError):
+            return HttpResponse(
+                "Corrupted HTTP_AUTHORIZATION header, bad base64 encoding",
+                status=400,
+            )
+        try:
+            username, secret = decoded_value.split(":", 1)
+        except ValueError:
+            return HttpResponse(
+                "Corrupted HTTP_AUTHORIZATION header, no user:pass", status=400
+            )
+        user = AuthToken.get_user_for_secret(username, secret)
+        if user is None:
+            response = HttpResponse("Invalid token", status=401)
+            response["WWW-Authenticate"] = 'Basic realm="XML-RPC Authentication token"'
+            return response
+    else:
+        user = request.user
+
+    result = dispatcher.marshalled_dispatch(raw_data, user, request)
+    response = HttpResponse(content_type="application/xml")
+    response.write(result)
+    response["Content-length"] = str(len(response.content))
+    return response
+
 
 @BreadCrumb("API help", parent=lava_index)
 def help(request, mapper, template_name="linaro_django_xmlrpc/api.html"):
