@@ -20,19 +20,19 @@
 
 import argparse
 import contextlib
+import grp
 import importlib
 import os
-from pathlib import Path
 import pwd
 import shutil
 import subprocess  # nosec - controlled inputs.
 import sys
 import tempfile
+from pathlib import Path
 
 from django.core.management.utils import get_random_secret_key
 from django.utils.crypto import get_random_string
 
-
 # Constants
 DEVICE_TYPES = Path("/usr/share/lava-server/device-types/")
 DISPATCHER_CONFIG = Path("/etc/lava-server/dispatcher-config/")
@@ -115,12 +115,29 @@ WHERE NOT EXISTS (SELECT FROM pg_database WHERE datname = '{devel_db}')\\gexec
         os.seteuid(uid)
 
 
+@contextlib.contextmanager
+def using_account(user, group):
+    euid = os.geteuid()
+    egid = os.getegid()
+    tuid = pwd.getpwnam(user).pw_uid
+    tgid = grp.getgrnam(group).gr_gid
+    try:
+        os.setegid(tgid)
+        os.seteuid(tuid)
+        yield None
+    finally:
+        os.seteuid(euid)
+        os.setegid(egid)
+
+
 def update_database():
-    run(
-        ["lava-server", "manage", "migrate", "--noinput", "--fake-initial"], "migration"
-    )
-    run(["lava-server", "manage", "drop_materialized_views"], "materialized views")
-    run(["lava-server", "manage", "refresh_queries", "--all"], "refresh_queries")
+    with using_account(LAVA_SYS_USER, LAVA_SYS_USER):
+        run(
+            ["lava-server", "manage", "migrate", "--noinput", "--fake-initial"],
+            "migration",
+        )
+        run(["lava-server", "manage", "drop_materialized_views"], "materialized views")
+        run(["lava-server", "manage", "refresh_queries", "--all"], "refresh_queries")
 
 
 def load_configuration():
