@@ -23,15 +23,15 @@ import os
 import unittest
 from unittest.mock import patch
 
-from lava_common.compat import yaml_safe_load
-from lava_common.exceptions import JobError, InfrastructureError
-from lava_common.timeout import Timeout
 import lava_dispatcher
+from lava_common.compat import yaml_safe_load
+from lava_common.exceptions import InfrastructureError, JobError
+from lava_common.timeout import Timeout
 from lava_dispatcher.actions.boot.ssh import SchrootAction
+from lava_dispatcher.protocols.multinode import MultinodeProtocol
+from lava_dispatcher.utils.filesystem import check_ssh_identity_file
 from tests.lava_dispatcher.test_basic import Factory, StdoutTestCase
 from tests.utils import infrastructure_error
-from lava_dispatcher.utils.filesystem import check_ssh_identity_file
-from lava_dispatcher.protocols.multinode import MultinodeProtocol
 
 
 class ConnectionFactory(Factory):
@@ -62,7 +62,7 @@ class TestConnection(StdoutTestCase):
         self.assertEqual([], self.job.pipeline.errors)
         # Check Pipeline
         description_ref = self.pipeline_reference("ssh-deploy.yaml", job=self.job)
-        self.assertEqual(description_ref, self.job.pipeline.describe(False))
+        self.assertEqual(description_ref, self.job.pipeline.describe())
 
     @unittest.skipIf(infrastructure_error("schroot"), "schroot not installed")
     def test_ssh_authorize(self):
@@ -276,7 +276,7 @@ class TestConnection(StdoutTestCase):
         description_ref = self.pipeline_reference(
             "bbb-ssh-guest.yaml", job=self.guest_job
         )
-        self.assertEqual(description_ref, self.guest_job.pipeline.describe(False))
+        self.assertEqual(description_ref, self.guest_job.pipeline.describe())
         self.guest_job.validate()
         multinode = [
             protocol
@@ -427,7 +427,7 @@ class TestConnection(StdoutTestCase):
         self.assertEqual(len(multinode), 1)
         # Check Pipeline
         description_ref = self.pipeline_reference("ssh-guest.yaml", job=self.guest_job)
-        self.assertEqual(description_ref, self.guest_job.pipeline.describe(False))
+        self.assertEqual(description_ref, self.guest_job.pipeline.describe())
 
 
 class TestConsoleConnections(StdoutTestCase):
