@@ -21,22 +21,23 @@
 
 import unittest
 from unittest.mock import patch
+
 from lava_common.compat import yaml_safe_load
-from lava_dispatcher.device import NewDevice
-from tests.utils import infrastructure_error, infrastructure_error_multi_paths
-from lava_dispatcher.actions.boot.grub import GrubMainAction
+from lava_common.exceptions import JobError
+from lava_dispatcher.action import Pipeline
 from lava_dispatcher.actions.boot import (
     BootloaderCommandOverlay,
     BootloaderInterruptAction,
 )
+from lava_dispatcher.actions.boot.grub import GrubMainAction
 from lava_dispatcher.actions.deploy.tftp import TftpAction
+from lava_dispatcher.device import NewDevice
 from lava_dispatcher.job import Job
-from lava_dispatcher.action import Pipeline
-from lava_common.exceptions import JobError
-from tests.lava_dispatcher.test_basic import Factory, StdoutTestCase
-from lava_dispatcher.utils.network import dispatcher_ip
 from lava_dispatcher.utils import filesystem
+from lava_dispatcher.utils.network import dispatcher_ip
 from lava_dispatcher.utils.strings import substitute
+from tests.lava_dispatcher.test_basic import Factory, StdoutTestCase
+from tests.utils import infrastructure_error, infrastructure_error_multi_paths
 
 
 class GrubFactory(Factory):
@@ -71,7 +72,7 @@ class TestGrubAction(StdoutTestCase):
 
         # uboot and uboot-ramdisk have the same pipeline structure
         description_ref = self.pipeline_reference("grub.yaml", job=job)
-        self.assertEqual(description_ref, job.pipeline.describe(False))
+        self.assertEqual(description_ref, job.pipeline.describe())
 
         self.assertIsNone(job.validate())
 
@@ -285,7 +286,7 @@ class TestGrubAction(StdoutTestCase):
         )
         job.validate()
         description_ref = self.pipeline_reference("grub-ramdisk-monitor.yaml", job=job)
-        self.assertEqual(description_ref, job.pipeline.describe(False))
+        self.assertEqual(description_ref, job.pipeline.describe())
 
     @patch(
         "lava_dispatcher.actions.deploy.tftp.which", return_value="/usr/bin/in.tftpd"
@@ -295,7 +296,7 @@ class TestGrubAction(StdoutTestCase):
         self.assertIsNotNone(job)
         job.validate()
         description_ref = self.pipeline_reference("mustang-grub-efi-nfs.yaml", job=job)
-        self.assertEqual(description_ref, job.pipeline.describe(False))
+        self.assertEqual(description_ref, job.pipeline.describe())
         grub = [
             action
             for action in job.pipeline.actions
@@ -320,7 +321,7 @@ class TestGrubAction(StdoutTestCase):
         self.assertIsNotNone(job)
         job.validate()
         description_ref = self.pipeline_reference("hikey-grub-efi.yaml", job=job)
-        self.assertEqual(description_ref, job.pipeline.describe(False))
+        self.assertEqual(description_ref, job.pipeline.describe())
 
     @unittest.skipIf(
         infrastructure_error_multi_paths(["lxc-info", "img2simg", "simg2img"]),
@@ -331,7 +332,7 @@ class TestGrubAction(StdoutTestCase):
         self.assertIsNotNone(job)
         job.validate()
         description_ref = self.pipeline_reference("hikey-console.yaml", job=job)
-        self.assertEqual(description_ref, job.pipeline.describe(False))
+        self.assertEqual(description_ref, job.pipeline.describe())
         console = [
             action
             for action in job.pipeline.actions
@@ -400,7 +401,7 @@ class TestGrubAction(StdoutTestCase):
         self.assertIsNotNone(job)
         job.validate()
         description_ref = self.pipeline_reference("hi960-grub-efi.yaml", job=job)
-        self.assertEqual(description_ref, job.pipeline.describe(False))
+        self.assertEqual(description_ref, job.pipeline.describe())
         deploy = [
             action
             for action in job.pipeline.actions
@@ -449,4 +450,4 @@ class TestGrubAction(StdoutTestCase):
         self.assertIsNotNone(job)
         job.validate()
         description_ref = self.pipeline_reference("synquacer_dtb.yaml", job=job)
-        self.assertEqual(description_ref, job.pipeline.describe(False))
+        self.assertEqual(description_ref, job.pipeline.describe())
