@@ -18,11 +18,14 @@
 # along
 # with this program; if not, see <http://www.gnu.org/licenses>.
 
-import pexpect
-import pytest
 import subprocess  # nosec - only for mocking
 import time
 
+import pexpect
+import pytest
+
+# This will be monkey patched
+import lava_dispatcher.actions.deploy.docker
 from lava_common.exceptions import (
     InfrastructureError,
     JobError,
@@ -30,12 +33,8 @@ from lava_common.exceptions import (
     TestError,
 )
 from lava_dispatcher.actions.test.interactive import TestInteractiveAction
-
 from tests.lava_dispatcher.test_basic import Factory, StdoutTestCase
 
-# This will be monkey patched
-import lava_dispatcher.actions.deploy.docker
-
 
 class InteractiveFactory(Factory):
     def create_interactive_job(self, device, filename):
@@ -51,7 +50,7 @@ def test_pipeline():
     description_ref = StdoutTestCase.pipeline_reference(
         "b2260-interactive.yaml", job=job
     )
-    assert description_ref == job.pipeline.describe(False)  # nosec
+    assert description_ref == job.pipeline.describe()  # nosec
 
 
 def test_bbb():
@@ -63,7 +62,7 @@ def test_bbb():
     description_ref = StdoutTestCase.pipeline_reference(
         "bbb-uboot-interactive.yaml", job=job
     )
-    assert description_ref == job.pipeline.describe(False)  # nosec
+    assert description_ref == job.pipeline.describe()  # nosec
 
 
 def test_stages(monkeypatch):
@@ -79,7 +78,7 @@ def test_stages(monkeypatch):
     description_ref = StdoutTestCase.pipeline_reference(
         "docker-interactive.yaml", job=job
     )
-    assert description_ref == job.pipeline.describe(False)  # nosec
+    assert description_ref == job.pipeline.describe()  # nosec
     assert (  # nosec  - assert is part of the test process.
         job.pipeline.actions[3].pipeline.actions[0].parameters["stage"] == 0
     )
