@@ -19,6 +19,7 @@
 # with this program; if not, see <http://www.gnu.org/licenses>.
 
 from unittest.mock import patch
+
 from tests.lava_dispatcher.test_basic import Factory, StdoutTestCase
 
 
@@ -36,4 +37,4 @@ class TestUserCommand(StdoutTestCase):
         job = factory.create_b2260_job("sample_jobs/b2260-user-command.yaml")
         job.validate()
         description_ref = self.pipeline_reference("b2260-user-command.yaml", job=job)
-        self.assertEqual(description_ref, job.pipeline.describe(False))
+        self.assertEqual(description_ref, job.pipeline.describe())
