@@ -1,42 +1,38 @@
 import os
-import yaml
-import jinja2
 import unittest
+from unittest import TestCase
 from unittest.mock import patch
 
+import yaml
 from django.conf import settings
+from django.contrib.auth.models import User
+from jinja2 import TemplateError as JinjaTemplateError
 
 from lava_common.compat import yaml_safe_dump, yaml_safe_load
-from lava_scheduler_app.models import (
-    Device,
-    DeviceType,
-    TestJob,
-    Tag,
-    DevicesUnavailableException,
-    _pipeline_protocols,
-)
-from lava_scheduler_app.dbutils import match_vlan_interface
-from lava_results_app.dbutils import _get_action_metadata
-from django.contrib.auth.models import User
-from lava_scheduler_app.utils import split_multinode_yaml
-from tests.lava_scheduler_app.test_submission import ModelFactory, TestCaseWithFactory
-from lava_scheduler_app.schema import (
-    validate_submission,
-    validate_device,
-    SubmissionException,
-)
-
-from lava_common.compat import yaml_unsafe_load
+from lava_common.constants import SYS_CLASS_KVM
+from lava_common.exceptions import InfrastructureError, JobError
+from lava_dispatcher.actions.boot.qemu import BootQEMU
 from lava_dispatcher.device import PipelineDevice
 from lava_dispatcher.parser import JobParser
-from tests.lava_dispatcher.test_defs import check_missing_path
-from lava_common.exceptions import JobError, InfrastructureError
-from lava_dispatcher.actions.boot.qemu import BootQEMU
 from lava_dispatcher.protocols.multinode import MultinodeProtocol
-from lava_common.constants import SYS_CLASS_KVM
+from lava_scheduler_app.dbutils import match_vlan_interface
+from lava_scheduler_app.models import (
+    Device,
+    DevicesUnavailableException,
+    DeviceType,
+    Tag,
+    TestJob,
+    _pipeline_protocols,
+)
+from lava_scheduler_app.schema import (
+    SubmissionException,
+    validate_device,
+    validate_submission,
+)
+from lava_scheduler_app.utils import split_multinode_yaml
+from tests.lava_dispatcher.test_defs import check_missing_path
+from tests.lava_scheduler_app.test_submission import ModelFactory, TestCaseWithFactory
 from tests.utils import DummyLogger
-from unittest import TestCase
-
 
 # set to True to see extra processing details
 DEBUG = False
@@ -440,7 +436,7 @@ class TestPipelineSubmit(TestCaseWithFactory):
 
         try:
             device_config = device.load_configuration(job_ctx)  # raw dict
-        except (jinja2.TemplateError, yaml.YAMLError, OSError) as exc:
+        except (JinjaTemplateError, yaml.YAMLError, OSError) as exc:
             # FIXME: report the exceptions as useful user messages
             self.fail("[%s] jinja2 error: %s" % (job.id, exc))
         if not device_config or not isinstance(device_config, dict):
@@ -591,7 +587,7 @@ class TestYamlMultinode(TestCaseWithFactory):
 
         try:
             device_config = device.load_configuration(job_ctx)  # raw dict
-        except (jinja2.TemplateError, yaml.YAMLError, OSError) as exc:
+        except (JinjaTemplateError, yaml.YAMLError, OSError) as exc:
             # FIXME: report the exceptions as useful user messages
             self.fail("[%d] jinja2 error: %s" % (host_job.id, exc))
         if not device_config or not isinstance(device_config, dict):
@@ -1021,7 +1017,7 @@ class TestYamlMultinode(TestCaseWithFactory):
 
                 try:
                     device_config = device.load_configuration(job_ctx)  # raw dict
-                except (jinja2.TemplateError, yaml.YAMLError, OSError) as exc:
+                except (JinjaTemplateError, yaml.YAMLError, OSError) as exc:
                     # FIXME: report the exceptions as useful user messages
                     self.fail("[%d] jinja2 error: %s" % (job.id, exc))
                 if not device_config or not isinstance(device_config, dict):
@@ -1090,67 +1086,6 @@ class TestYamlMultinode(TestCaseWithFactory):
         job_list = TestJob.from_yaml_and_user(yaml_safe_dump(submission), user)
         self.assertEqual(len(job_list), 2)
 
-    def test_multinode_v2_metadata(self):
-        device_type = self.factory.make_device_type()
-        self.factory.make_device(device_type, "fakeqemu1")
-        self.factory.make_device(device_type, "fakeqemu2")
-        client_submission = yaml_safe_load(
-            open(
-                os.path.join(
-                    os.path.dirname(__file__),
-                    "sample_jobs",
-                    "kvm-multinode-client.yaml",
-                ),
-                "r",
-            )
-        )
-        job_ctx = client_submission.get("context", {})
-        device = Device.objects.get(hostname="fakeqemu1")
-        device_config = device.load_configuration(job_ctx)  # raw dict
-        self.assertTrue(device.is_valid())
-        parser_device = PipelineDevice(device_config)
-        parser = JobParser()
-        pipeline_job = parser.parse(
-            yaml_safe_dump(client_submission), parser_device, 4212, None, ""
-        )
-        pipeline = pipeline_job.describe()
-
-        meta_dict = _get_action_metadata(pipeline["job"]["actions"])
-        self.assertEqual(
-            {
-                "test.0.common.definition.name": "multinode-basic",
-                "test.0.common.definition.path": "lava-test-shell/multi-node/multinode01.yaml",
-                "test.0.common.definition.from": "git",
-                "boot.0.common.method": "qemu",
-                "test.0.common.definition.repository": "http://git.linaro.org/lava-team/lava-functional-tests.git",
-            },
-            meta_dict,
-        )
-        # simulate dynamic connection
-        dynamic = yaml_unsafe_load(  # nosec - not suitable for safe_load
-            open(
-                os.path.join(
-                    os.path.dirname(__file__),
-                    "pipeline_refs",
-                    "connection-description.yaml",
-                ),
-                "r",
-            )
-        )
-        meta_dict = _get_action_metadata(dynamic["job"]["actions"])
-        self.assertEqual(
-            meta_dict,
-            {
-                "omitted.1.inline.name": "ssh-client",
-                "test.0.definition.repository": "git://git.linaro.org/lava-team/lava-functional-tests.git",
-                "test.0.definition.name": "smoke-tests",
-                "boot.0.method": "ssh",
-                "omitted.1.inline.path": "inline/ssh-client.yaml",
-                "test.0.definition.from": "git",
-                "test.0.definition.path": "lava-test-shell/smoke-tests-basic.yaml",
-            },
-        )
-
     @unittest.skipIf(not os.path.exists(SYS_CLASS_KVM), "Cannot use --enable-kvm")
     def test_multinode_mixed_deploy(self):
         user = self.factory.make_user()
@@ -1192,7 +1127,7 @@ class TestYamlMultinode(TestCaseWithFactory):
 
                 try:
                     device_config = device.load_configuration(job_ctx)  # raw dict
-                except (jinja2.TemplateError, yaml.YAMLError, OSError) as exc:
+                except (JinjaTemplateError, yaml.YAMLError, OSError) as exc:
                     # FIXME: report the exceptions as useful user messages
                     self.fail("[%d] jinja2 error: %s" % (job.id, exc))
                 if not device_config or not isinstance(device_config, dict):
