@@ -1,6 +1,6 @@
+import json
 import logging
 import os
-import json
 
 from django.contrib.auth.models import Group, Permission, User
 from django.test import TestCase
@@ -10,8 +10,8 @@ from lava_scheduler_app.dbutils import testjob_submission
 from lava_scheduler_app.models import (
     Alias,
     Device,
-    DeviceType,
     DevicesUnavailableException,
+    DeviceType,
     NotificationCallback,
     Tag,
     TestJob,
@@ -19,7 +19,6 @@ from lava_scheduler_app.models import (
 from lava_scheduler_app.notifications import create_notification
 from linaro_django_xmlrpc.models import AuthToken
 
-
 # pylint gets confused with TestCase
 
 
@@ -175,7 +174,7 @@ class TestTestJob(TestCaseWithFactory):
         user.save()
         user = User.objects.get(username=user.username)
         self.assertEqual(
-            {u"lava_scheduler_app.change_device"}, user.get_all_permissions()
+            {"lava_scheduler_app.change_device"}, user.get_all_permissions()
         )
         self.assertTrue(user.has_perm("lava_scheduler_app.change_device"))
 
